@@ -1,38 +1,41 @@
+import ee;
+
 from .sql2gee import SQL2GEE
-import ee; ee.Initialize()
+
+ee.Initialize()
 from .utils.jsonSql import JsonSql
 
 ### For debugging and testing
-#import pdb; pdb.set_trace()
-#from pympler.tracker  import SummaryTracker
-#import cProfile, pstats, io
-#tracker = SummaryTracker()
-#pr = cProfile.Profile()
-#pr.enable()
+# import pdb; pdb.set_trace()
+# from pympler.tracker  import SummaryTracker
+# import cProfile, pstats, io
+# tracker = SummaryTracker()
+# pr = cProfile.Profile()
+# pr.enable()
 
 
 ## Feature Collection 
-#sql = "select sum(mean_elev), count(mean_elev) from 'GLIMS/2016' group by glac_name, rec_status order by glac_name limit 20"
+# sql = "select sum(mean_elev), count(mean_elev) from 'GLIMS/2016' group by glac_name, rec_status order by glac_name limit 20"
 
 ## Image Collection 
 
-#sql = "select count(pr), avg(tmmn) from 'IDAHO_EPSCOR/GRIDMET' where system:time_start > 284191200000 and ST_INTERSECTS(ST_SetSRID(ST_GeomFromGeoJSON('{\"type\":\"Polygon\",\"coordinates\":[[[-5.273512601852417,42.81137220349083],[-5.273512601852417,42.811803118457306],[-5.272732079029083,42.811803118457306],[-5.272732079029083,42.81137220349083],[-5.273512601852417,42.81137220349083]]]}'), 4326), the_geom) order by system:time_start asc limit 10"
+# sql = "select count(pr), avg(tmmn) from 'IDAHO_EPSCOR/GRIDMET' where system:time_start > 284191200000 and ST_INTERSECTS(ST_SetSRID(ST_GeomFromGeoJSON('{\"type\":\"Polygon\",\"coordinates\":[[[-5.273512601852417,42.81137220349083],[-5.273512601852417,42.811803118457306],[-5.272732079029083,42.811803118457306],[-5.272732079029083,42.81137220349083],[-5.273512601852417,42.81137220349083]]]}'), 4326), the_geom) order by system:time_start asc limit 10"
 sql = "SELECT ST_HISTOGRAM(raster, lossyear, 15, true) FROM 'UMD/hansen/global_forest_change_2015'"
 
 myQuery = SQL2GEE(JsonSql(sql).to_json())
 
-#pdb.run('myQuery.response()')
-#print(myQuery.metadata)
+# pdb.run('myQuery.response()')
+# print(myQuery.metadata)
 print(myQuery.response)
 
-#pr.disable()
-#pr.dump_stats('test_file')
-#s = io.StringIO()
-#sortby = 'cumulative'
-#ps = pstats.Stats(pr, stream=s).sort_stats(sortby)
-#ps.print_stats()
-#print(s.getvalue())
-#tracker.print_diff()
+# pr.disable()
+# pr.dump_stats('test_file')
+# s = io.StringIO()
+# sortby = 'cumulative'
+# ps = pstats.Stats(pr, stream=s).sort_stats(sortby)
+# ps.print_stats()
+# print(s.getvalue())
+# tracker.print_diff()
 
 # -- ASSETS
 # -- Image Collections: -- 'COPERNICUS/S2', 'HYCOM/GLBu0_08/sea_temp_salinity', 'IDAHO_EPSCOR/GRIDMET'
@@ -54,6 +57,6 @@ print(myQuery.response)
 # select sum(area) from 'GLIMS/2016' where max_elev > 3000
 # select sum(area), anlys_time from 'GLIMS/2016'  group by anlys_time order by anlys_time asc limit 10
 
-#--- Image 'UMD/hansen/global_forest_change_2015'
+# --- Image 'UMD/hansen/global_forest_change_2015'
 # SELECT ST_HISTOGRAM(raster, lossyear, 15, true) FROM 'UMD/hansen/global_forest_change_2015'
 #
